@@ -5,14 +5,22 @@ from sys import exit
 from ast import literal_eval
 from typing import Any, Dict
 from cosecurity_amqp_lib.logger import logger
-from pika import BlockingConnection, ConnectionParameters
+from pika import BlockingConnection, URLParameters
 
 
 class Consumer:
     """
     queue consumer with a general handler to handle posted messages
     """
-    def __init__(self, name:str) -> None:
+    def __init__(self, name:str, socket_timeout:int=5) -> None:
+        self._user = os.getenv('AMQP_USER', None)
+        if self._user is None:
+            raise Exception('The environment variable AMQP_USER is required for operation')
+            
+        self._password = os.getenv('AMQP_PASSWORD', None)
+        if self._password is None:
+            raise Exception('The environment variable AMQP_PASSWORD is required for operation')
+
         self._host = os.getenv('AMQP_HOST', None)
         if self._host is None:
             raise Exception('The environment variable AMQP_HOST is required for operation')
@@ -26,6 +34,7 @@ class Consumer:
         if self._queue_name is None:
             raise Exception('Queue not found in configuration file, please review!')
 
+        self._socket_timeout = socket_timeout
         self._name = name
         self._handlers = {}
 
@@ -38,19 +47,18 @@ class Consumer:
 
     def start(self) -> None:
         try:
-            self._connection = BlockingConnection(
-                ConnectionParameters(
-                    host=self._host, 
-                    heartbeat=self._heartbeat
-                )
-            )
+            params = URLParameters(f'amqp://{self._user}:{self._password}@{self._host}')
+            params.socket_timeout = self._socket_timeout
+            params.heartbeat = self._heartbeat
+
+            self._connection = BlockingConnection(params)
             self._channel = self._connection.channel()
-            self._channel.queue_declare(queue=self._queue_name)
+            self._channel.queue_declare(queue=self._queue_name, durable=1)
 
             self._channel.basic_consume(
                 queue=self._queue_name,
                 on_message_callback=self._callback_method,
-                auto_ack=True
+                auto_ack=False
             )
 
             logger.info(f'{self._name} initialized')
