@@ -44,7 +44,7 @@ class ObjectDetectionStub(Stub):
             destination='object_detection'
         )
 
-    def find(self, image_id:str, image:np.ndarray) -> None:
+    def find(self, image_id:int, image:np.ndarray) -> None:
         self._send(
             primitive='find',  
             content={
@@ -52,3 +52,22 @@ class ObjectDetectionStub(Stub):
                 'image': image
             }
         )
+
+class FaceDetectionStub(Stub):
+    def __init__(self):
+        super().__init__(
+            destination='face_detection'
+        )
+
+    def find(self, detected_object_id:int, image:np.ndarray, x:int, y:int, w:int, h:int) -> None:
+        self._send(
+            primitive='find',  
+            content={
+                'detected_object_id': detected_object_id,
+                'image': image,
+                'x': x,
+                'y': y,
+                'w': w,
+                'h': h
+            }
+        )
\ No newline at end of file
